@@ -47,7 +47,7 @@ def _try_extractors(environ, start_response):
         extractor = imported_module.Extractor()
         extracted_user = extractor.extract(environ, start_response)
         if extracted_user:
-            logging.debug('UserExtract:%s found %s' %
-                    (extractor_name, extracted_user))
+            logging.debug('UserExtract:%s found %s',
+                    extractor_name, extracted_user)
             return extracted_user
     return False
