@@ -309,7 +309,7 @@ def _put_tiddler(environ, start_response, tiddler):
     except NoTiddlerError, exc:
         raise HTTP404('Unable to put tiddler, %s. %s' % (tiddler.title, exc))
 
-    etag = ('Etag', _tiddler_etag(tiddler))
+    etag = ('Etag', _tiddler_etag(environ, tiddler))
     response = [('Location', web.tiddler_url(environ, tiddler))]
     if etag:
         response.append(etag)
@@ -353,7 +353,7 @@ def _validate_tiddler_headers(environ, tiddler):
     b) we have edit contention when trying to write.
     """
     request_method = environ['REQUEST_METHOD']
-    tiddler_etag = _tiddler_etag(tiddler)
+    tiddler_etag = _tiddler_etag(environ, tiddler)
 
     logging.debug('attempting to validate %s with revision %s',
             tiddler.title, tiddler.revision)
@@ -362,27 +362,43 @@ def _validate_tiddler_headers(environ, tiddler):
     last_modified = None
     if request_method == 'GET':
         incoming_etag = environ.get('HTTP_IF_NONE_MATCH', None)
-        if incoming_etag == tiddler_etag:
-            raise HTTP304(incoming_etag)
-        last_modified_string = web.http_date_from_timestamp(tiddler.modified)
-        last_modified = ('Last-Modified', last_modified_string)
-        incoming_modified = environ.get('HTTP_IF_MODIFIED_SINCE', None)
-        if incoming_modified and \
-                (web.datetime_from_http_date(incoming_modified) >=
-                        web.datetime_from_http_date(last_modified_string)):
-            raise HTTP304('')
+        if incoming_etag:
+            logging.debug('attempting to validate incoming etag(GET):'
+                '%s against %s', incoming_etag, tiddler_etag)
+            if incoming_etag == tiddler_etag:
+                raise HTTP304(incoming_etag)
+        else:
+            last_modified_string = web.http_date_from_timestamp(
+                    tiddler.modified)
+            last_modified = ('Last-Modified', last_modified_string)
+            incoming_modified = environ.get('HTTP_IF_MODIFIED_SINCE', None)
+            if incoming_modified and \
+                    (web.datetime_from_http_date(incoming_modified) >=
+                            web.datetime_from_http_date(last_modified_string)):
+                raise HTTP304('')
 
     else:
         incoming_etag = environ.get('HTTP_IF_MATCH', None)
-        logging.debug('attempting to validate incoming etag: %s against %s',
-                incoming_etag, tiddler_etag)
-        if incoming_etag and incoming_etag != tiddler_etag:
+        logging.debug('attempting to validate incoming etag(PUT):'
+            '%s against %s', incoming_etag, tiddler_etag)
+        if incoming_etag and not _etag_write_match(incoming_etag, tiddler_etag):
             raise HTTP412('Provided ETag does not match. '
                 'Server content probably newer.')
     etag = ('Etag', '%s' % tiddler_etag)
     return last_modified, etag
 
 
+def _etag_write_match(incoming_etag, server_etag):
+    """
+    Compare two tiddler etags for a satisfactory match
+    for a PUT or DELETE. This means comparing without the
+    content type that _may_ be on the end.
+    """
+    incoming_etag = incoming_etag.split(';', 1)[0].strip('"')
+    server_etag = server_etag.split(';', 1)[0].strip('"')
+    return (incoming_etag == server_etag)
+
+
 def _send_tiddler(environ, start_response, tiddler):
     """
     Push a single tiddler out the network in the
@@ -406,6 +422,26 @@ def _send_tiddler(environ, start_response, tiddler):
 
     # If we have content that doesn't look like wikitext,
     # we send it out straight up rather than using the serializer.
+    content, mime_type = _get_tiddler_content(environ, tiddler)
+
+    vary_header = ('Vary', 'Accept')
+    cache_header = ('Cache-Control', 'no-cache')
+    content_header = ('Content-Type', str(mime_type))
+    response = [cache_header, content_header, vary_header]
+    if last_modified:
+        response.append(last_modified)
+    if etag:
+        response.append(etag)
+    start_response("200 OK", response)
+
+    return [content]
+
+
+def _get_tiddler_content(environ, tiddler):
+    """
+    Extract the content of the tiddler, either straight up if
+    the content is not considered text, or serialized if it is
+    """
     if _not_wikitext(tiddler, environ['tiddlyweb.config']):
         mime_type = tiddler.type
         content = tiddler.text
@@ -418,17 +454,7 @@ def _send_tiddler(environ, start_response, tiddler):
             content = serializer.to_string()
         except TiddlerFormatError, exc:
             raise HTTP415(exc)
-
-    cache_header = ('Cache-Control', 'no-cache')
-    content_header = ('Content-Type', str(mime_type))
-    response = [cache_header, content_header]
-    if last_modified:
-        response.append(last_modified)
-    if etag:
-        response.append(etag)
-    start_response("200 OK", response)
-
-    return [content]
+    return content, mime_type
 
 
 def _not_wikitext(tiddler, config):
@@ -477,18 +503,19 @@ def _new_tiddler_etag(tiddler):
     yet exist. This is a bastardization of ETag handling
     but is useful for doing edit contention handling.
     """
-    return str('"%s/%s/%s"' %
-            (urllib.quote(tiddler.bag.encode('utf-8'), safe=''),
-                urllib.quote(tiddler.title.encode('utf-8'), safe=''),
-                '0'))
+    return str('"%s/%s/%s"' % (web.encode_name(tiddler.bag),
+        web.encode_name(tiddler.title), '0'))
 
 
-def _tiddler_etag(tiddler):
+def _tiddler_etag(environ, tiddler):
     """
     Calculate the ETAG of a tiddler, based on
     bag name, tiddler title and revision.
     """
-    return str('"%s/%s/%s"' %
-            (urllib.quote(tiddler.bag.encode('utf-8'), safe=''),
-                urllib.quote(tiddler.title.encode('utf-8'), safe=''),
-                tiddler.revision))
+    try:
+        mime_type = web.get_serialize_type(environ)[1]
+        mime_type = mime_type.split(';', 1)[0].strip()
+    except TypeError:
+        mime_type = ''
+    return str('"%s/%s/%s;%s"' % (web.encode_name(tiddler.bag),
+        web.encode_name(tiddler.title), tiddler.revision, mime_type))
