@@ -40,7 +40,8 @@ def send_tiddlers(environ, start_response, bag):
 
     content_header = ('Content-Type', mime_type)
     cache_header = ('Cache-Control', 'no-cache')
-    response = [content_header, cache_header]
+    vary_header = ('Vary', 'Accept')
+    response = [content_header, cache_header, vary_header]
 
     if download:
         response.append(('Content-Disposition',
@@ -83,8 +84,13 @@ def _validate_tiddler_list(environ, bag):
         last_modified_string = http_date_from_timestamp(last_modified_number)
         last_modified = ('Last-Modified', last_modified_string)
 
-    etag_string = '"%s:%s"' % (_sha_tiddler_titles(bag),
-            last_modified_number)
+    try:
+        serialize_type, mime_type = get_serialize_type(environ)
+        mime_type = mime_type.split(';', 1)[0].strip()
+    except TypeError:
+        mime_type = ''
+    etag_string = '"%s:%s;%s"' % (_sha_tiddler_titles(bag),
+            last_modified_number, mime_type)
     etag = ('Etag', etag_string)
 
     incoming_etag = environ.get('HTTP_IF_NONE_MATCH', None)
